==> haskell-dec-0.0.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dec
version:              0.0.5
visibility:           public
id:                   dec-0.0.5-LudXni7GAoCESRm5TpcXOv
key:                  dec-0.0.5-LudXni7GAoCESRm5TpcXOv
license:              BSD-3-Clause
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Neg a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Neg a)
    @

category:             Data, Dependent Types
abi:                  562c47cdf26ca5ef40a12259b1d38b39
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dec-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dec
hs-libraries:         HSdec-0.0.5-LudXni7GAoCESRm5TpcXOv
depends:              base-4.17.2.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dec-0.0.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dec
version:              0.0.6
visibility:           public
id:                   dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ
key:                  dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ
license:              BSD-3-Clause
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/dec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Neg a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Neg a)
    @

category:             Data, Dependent Types
abi:                  ce7bf3948a8cbeb15eaf4717c53f60f1
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dec-0.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dec-0.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dec-0.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dec
hs-libraries:         HSdec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ
depends:              base-4.17.2.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
